#
# spec file for package python-geventhttpclient
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-geventhttpclient
Version:        2.3.1
Release:        1.2
Summary:        HTTP client library for gevent
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/gwik/geventhttpclient
Source:         https://files.pythonhosted.org/packages/source/g/geventhttpclient/geventhttpclient-%{version}.tar.gz
# Needed for tests
Source1:        https://github.com/gwik/geventhttpclient/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  %{python_module Brotli}
BuildRequires:  %{python_module certifi}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module dpkt}
BuildRequires:  %{python_module gevent}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
%if 0%{?suse_version} <= 1500
BuildRequires:  python-mock
%endif
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Brotli
Requires:       python-certifi
Requires:       python-gevent
Requires:       python-urllib3
%python_subpackages

%description
A concurrent HTTP client library for Python using gevent.

geventhttpclient uses a HTTP parser, written in C, originating from
nginx, extracted and modified by Joyent.

geventhttpclient has been designed for high concurrency and
streaming, and supports HTTP/1.1 persistent connections. More
generally, it is designed for pulling from REST APIs and streaming
APIs like Twitter's.

%prep
%autosetup -p1 -n geventhttpclient-%{version}
tar -xvf %{SOURCE1} geventhttpclient-%{version}/tests/

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
# test_cookielib_compatibility https://github.com/gwik/geventhttpclient/issues/119
# test_no_module_ssl.py https://github.com/geventhttpclient/geventhttpclient/issues/180
%pytest_arch -m 'not network' -k 'not (test_cookielib_compatibility or test_no_module_ssl)'

%files %{python_files}
%doc README.md
%license LICENSE-MIT
%{python_sitearch}/geventhttpclient
%{python_sitearch}/geventhttpclient-%{version}*-info

%changelog
* Tue Oct  8 2024 Daniel Garcia <daniel.garcia@suse.com>
- Update to 2.3.1:
  * Fix locust backwards compatibility by @ml31415 in #218
- 2.3.0:
  * Clean up readme and example code by @ml31415 in #212
  * Fix for #179 and improved multipart form handling by @ml31415 in #213
  * requests compatibility layer by @ml31415 in #209
  * Fixed #186 and improved package build by @ml31415 in #214
  * Add pre-commit hooks by @ml31415 in #215
  * Add requests compatibility to README by @ml31415 in #216
- 2.2.1:
  * URL refactoring by @ml31415 in #206
  * Switch default ssl protocol to PROTOCOL_TLS_CLIENT and improve tests by @ml31415 in #207
  * Fixes #40 max_retries and max_redirects by @ml31415 in #208
  * Use test.pypi.org before publishing by @ml31415 in #211
- 2.2.0:
  * Fixes http.client patching by @ml31415 in #200
  * Better headers by @ml31415 in #203
- 2.1.1:
  * Reduce httpbin dependency by @ml31415 in #199
  * Fix publishing build issue by @ml31415 in #201
- 2.1.0:
  * Spring cleaning (mostly test updates) by @ml31415 in #191
  * Drop support for outdated python and gevent versions by @ml31415 in #192
  * Upgrade llhttp v6.0.11 by @ml31415 in #193
  * Github actions and project metadata improvements by @ml31415 in #195
  * Benchmarks updated; some tests parametrized by @ml31415 in #196
  * More spring cleaning by @ml31415 in #197
- 2.0.12:
  * port examples to Python3 by @a-detiste in #185
  * add response cookies to cookiejar before verify_status by @onestay in #188
* Thu Dec  7 2023 Dirk Müller <dmueller@suse.com>
- update to 2.0.11:
  * Support Python 3.12
  * Disable unit tests for no ssl module + fixes for build
* Fri Aug 25 2023 Markéta Machová <mmachova@suse.com>
- Skip both tests in test_no_module_ssl.py, failing with new gevent
* Thu May  4 2023 Dirk Müller <dmueller@suse.com>
- update to 2.0.9:
  * Add square brackets for Host header when using IPv6 address
  * Enable ppc64le wheels
* Fri Nov  4 2022 pgajdos@suse.com
- version update to 2.0.8
  * lot of changes, see
    https://github.com/geventhttpclient/geventhttpclient/releases
- do not require python-six
- deleted patches
  - remove_mock.patch (upstreamed)
* Tue Feb 16 2021 Ben Greiner <code@bnavigator.de>
- Update to 1.4.5
  * Don't auto parse query string. Add params keyword argument.
- don't try to set a nonexistend attribute for a test
  gh#gwik/geventhttpclient#137
* Mon Dec 14 2020 Benjamin Greiner <code@bnavigator.de>
- Fix condition around BuildRequirement
* Sun Dec 13 2020 Matej Cepl <mcepl@suse.com>
- We don't need to break Python 2.7
* Fri Dec 11 2020 Matej Cepl <mcepl@suse.com>
- Add remove_mock.patch to remove dependency on the external mock
  package (gh#gwik/geventhttpclient#135).
* Sat Aug  1 2020 John Vandenberg <jayvdb@gmail.com>
- Remove gevent-mark-tests.patch and LICENSE-MIT that are
  now incorporated upstream
- Update to v1.4.4
  * Add kwargs to exception objects representation
- from v1.4.3
  * Fix Unhandled UnicodeDecodeError exception if response with
    status 400 and request contains binary payload
- from v1.4.0
  * httpparser: update http parser to 2.9.4
* Tue Jan 14 2020 Tomáš Chvátal <tchvatal@suse.com>
- skip test test_cookielib_compatibility as it is borked upstream
* Fri Mar 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to skip online tests:
  * gevent-mark-tests.patch
* Thu Mar 14 2019 Jan Engelhardt <jengelh@inai.de>
- Reduce marketing wording in the description.
* Thu Mar 14 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.3.1:
  * no upstream changelog
- Switch to singlespec
- Enable tests
* Tue Sep  8 2015 tbechtold@suse.com
- Initial packaging (version 1.1.0)
